@@ -32,7 +32,7 @@ calc_test_stat_exponential_rate <- function(x, rate, alternative) {
 #' x <- rexp(100, 3)
 #' exponential_rate_one_sample(x, 1, "greater")
 #' @export
-exponential_rate_one_sample <- LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_exponential_rate, rate, 0)
+exponential_rate_one_sample <- LRTesteR:::create_test_function_one_sample_case_one(LRTesteR:::calc_test_stat_exponential_rate, rate, 15, 0)
 
 #' @keywords internal
 calc_test_stat_exponential_rate_one_way <- function(x, fctr) {
@@ -89,4 +89,4 @@ calc_test_stat_exponential_rate_one_way <- function(x, fctr) {
 #' fctr <- factor(fctr, levels = c("1", "2", "3"))
 #' exponential_rate_one_way(x, fctr, .95)
 #' @export
-exponential_rate_one_way <- create_test_function_one_way_case_one(LRTesteR:::calc_test_stat_exponential_rate_one_way, exponential_rate_one_sample)
+exponential_rate_one_way <- create_test_function_one_way_case_one(LRTesteR:::calc_test_stat_exponential_rate_one_way, exponential_rate_one_sample, 30)
